@@ -31,7 +31,7 @@ def run(plan):
     skeddar = ioflo.app.run.run(  name=name,
                         filepath=plan,
                         period=0.0625,
-                        verbose=1,
+                        verbose=2,
                         real=False,)
 
     print("Running Plan: {0}\n".format(plan))
@@ -47,5 +47,5 @@ def run(plan):
 
 
 if __name__ == '__main__':
-    run('testResolveDoClause.flo')
+    run('testRearRaze.flo')
 
